==> jena-5.4.0-source-release.zip: jena-5.4.0/archived-modules.md <==
# Retired Apache Jena Modules

This file lists Jena module that have been retired and are no longer part of a
release. For each module, the location of the last code in git is given.

Retired modules can be incorporated back into Jena releases if there is
sufficient activity to maintain the code over the long term.

### Apache Jena JDBC

The last release of apache-jena-osgi source was with Jena 4.10.0 on 2023-@@
Source is available from git with tag "jena-4.10.0".
The commit retiring jena-jdbc is @@
@@ needs setting after merge - commit is 2023-10-12, "GH-2035: Retire jena-jdbc"

### Apache Jena OSGi

The last release of apache-jena-osgi source was with Jena 4.2.0 on 2021-09-16.
The last release of the OSGi binary artifacts was with Jena 4.1.0 2021-06-04.
Source is available from git with tag "jena-4.2.0".
The commit retiring apache-jena-osgi is 79a477c00e.

### Apache Jena SDB

The last release of jena-sdb was with Jena 3.17.0 on 2020-12-01.
Source is available from git with tag "jena-3.17.0".
The last git commit after 3.17.0 to jena-sdb was fbd27b04e4.
This contains changes made in the progress to Jena 4.0.0.

### Apache Jena Elephas

The last release of jena-elephas was with Jena 3.17.0 on 2020-12-01.
Source is available from git with tag "jena-3.17.0".
The last git commit after 3.17.0 to jena-elephas was cb458d4c7b.
This contains changes made in the progress to Jena 4.0.0.

### Apache Jena text-es

The last release of jena-text-es was with Jena 3.17.0 on 2020-12-01.
Source is available from git with tag "jena-3.17.0".
The last git commit after 3.17.0 to jena-text-es was cc37b7067a.

### Apache Jena Spatial

The last release of jena-spatial was with Jena 3.12.0 on 2019-05-27.
The code for this module has been removed.
Source is available from git with tag "jena-3.12.0".

### Apache Jena CSV

The last release of this module was with Jena 3.9.0 on 2018-10-27.
The code for this module has been deleted. 
It is available from git with tag "jena-3.9.0".

### Apache Jena Fuseki1

The last release of Fuseki1 was with Jena 3.9.0 on 2018-10-27.
The code for this module has been deleted.  
Source is available from git with tag "jena-3.9.0".

See [Apache Jena Fuseki2](jena-fuseki2) for an up-to-date 
SPARQL triplestore.

### Apache Jena Maven Tools

The last release of this module was with Jena 3.6.0 on 2017-12-13.
The code for this module has been deleted. 
It is available from git with tag "jena-3.6.0".

==> jena-5.6.0-source-release.zip: jena-5.6.0/archived-modules.md <==
# Retired Apache Jena Modules

This file lists Jena module that have been retired and are no longer part of a
release. For each module, the location of the last code in git is given.

Retired modules can be incorporated back into Jena releases if there is
sufficient activity to maintain the code over the long term.

### Apache Jena JDBC

The last release of jena-jdbc was with Jena 4.10.0.
The source code is available from git with tag "jena-4.10.0".
The commit retiring jena-jdbc is ec83436844.

### Apache Jena OSGi

The last release of apache-jena-osgi source was with Jena 4.2.0 on 2021-09-16.
The last release of the OSGi binary artifacts was with Jena 4.1.0 2021-06-04.
Source is available from git with tag "jena-4.2.0".
The commit retiring apache-jena-osgi is 79a477c00e.

### Apache Jena SDB

The last release of jena-sdb was with Jena 3.17.0 on 2020-12-01.
Source is available from git with tag "jena-3.17.0".
The last git commit after 3.17.0 to jena-sdb was fbd27b04e4.
This contains changes made in the progress to Jena 4.0.0.

### Apache Jena Elephas

The last release of jena-elephas was with Jena 3.17.0 on 2020-12-01.
Source is available from git with tag "jena-3.17.0".
The last git commit after 3.17.0 to jena-elephas was cb458d4c7b.
This contains changes made in the progress to Jena 4.0.0.

### Apache Jena text-es

The last release of jena-text-es was with Jena 3.17.0 on 2020-12-01.
Source is available from git with tag "jena-3.17.0".
The last git commit after 3.17.0 to jena-text-es was cc37b7067a.

### Apache Jena Spatial

The last release of jena-spatial was with Jena 3.12.0 on 2019-05-27.
The code for this module has been removed.
Source is available from git with tag "jena-3.12.0".

### Apache Jena CSV

The last release of this module was with Jena 3.9.0 on 2018-10-27.
The code for this module has been deleted. 
It is available from git with tag "jena-3.9.0".

### Apache Jena Fuseki1

The last release of Fuseki1 was with Jena 3.9.0 on 2018-10-27.
The code for this module has been deleted.  
Source is available from git with tag "jena-3.9.0".

See [Apache Jena Fuseki2](jena-fuseki2) for an up-to-date 
SPARQL triplestore.

### Apache Jena Maven Tools

The last release of this module was with Jena 3.6.0 on 2017-12-13.
The code for this module has been deleted. 
It is available from git with tag "jena-3.6.0".
